@@ -17,7 +17,8 @@
 
 import sys
 import os
-from os.path import join, abspath, dirname, splitext, split
+from os.path import join, abspath, dirname, splitext, split, exists
+import inspect
 
 import cherrypy
 
@@ -41,7 +42,7 @@ class Server(object):
         self.status = ServerStatus.Unknown
         self.root_dir = root_dir
         self.context = context or Context(root_dir=root_dir)
-        self.storm_stores = {}
+        self.template_filters = {}
         self.test_connection_error = None
         self.cache = None
 
@@ -62,6 +63,7 @@ class Server(object):
             from storm.tracer import debug
             debug(True, stream=sys.stdout)
 
+        self.import_template_filters()
         self.import_controllers()
 
         self.run_server(non_block)
@@ -69,6 +71,13 @@ class Server(object):
         self.status = ServerStatus.Started
         self.publish('on_after_server_start', {'server':self, 'context':self.context})
 
+    def import_template_filters(self):
+        if exists(abspath(join(self.root_dir, "template_filters.py"))):
+            template_filters = Server.imp("template_filters")
+            for name, func in inspect.getmembers(template_filters):
+                if inspect.isfunction(func) and not name.startswith("_"):
+                    self.template_filters[name] = func
+
     def import_controllers(self):
         controller_path = self.context.settings.Ion.controllers_path
         controller_path = controller_path.lstrip("/") or "controllers"
